/* Module      : JaegerMaze.h
 * Author      : Robert W. Lindeman
 * Email       : gogo@wpi.edu
 * Course      : IMGD 3000
 *
 * Description : This is header for the Maze class.
 *
 *               A maze is made up of a two-dimentional array of 'Cell'
 *               objects.
 *
 * Date        : 2006/02/06
 *
 * History:
 * Revision      Date          Changed By
 * --------      ----------    ----------
 * 00.01         2006/02/06    gogo
 * First release.
 *
 * (c) Copyright 2006, Worcester Polytechnic Institute.
 */

#ifndef _JAEGER_MAZE_H_
#define _JAEGER_MAZE_H_

/* -- INCLUDE FILES ------------------------------------------------------ */

#include "JaegerConstants.h"
#include "JaegerCell.h"

/* -- DATA STRUCTURES ---------------------------------------------------- */

class Maze  {
  private:
  public:
    Cell ***maze;       // Two-dimentional array of cells.
    int width;          // Width of the maze.
    int height;         // Height of maze.
    float seed;         // Random number seed for this maze.
    Maze::Maze( int w, int h ); // Constructor that allocates space.
    Maze::Maze( void ); // Constructor, no space allocation.
    Maze::~Maze( void ); // Destructor.
    bool Maze::GenerateDefaultMaze( float s ); // Method to build a maze.
    bool Maze::GenerateRandomMaze( float s ); // Method to build a maze.
    void Maze::Print( void ); // Method to print the maze to stdout.
    int Maze::Save( char *file ); // Save a maze to a file.
    int Maze::Load( char *file ); // Load a maze from a file.
    Cell *Maze::GetCell( int row, int col ) { return( this->maze[row][col] ); };

};

/* -- GLOBAL VARIABLES --------------------------------------------------- */

/* -- LOCAL VARIABLES ---------------------------------------------------- */

/* ----------------------------------------------------------------------- */

#endif
